@@ -1,13 +1,13 @@
 /* infodoc.c -- functions which build documentation nodes.
-   $Id: infodoc.c,v 1.8.2.1 2007/06/27 17:10:57 karl Exp $
+   $Id: infodoc.c,v 1.12 2007/07/01 21:20:30 karl Exp $
 
-   Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2007 Free Software
-   Foundation, Inc.
+   Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2006, 2007
+   Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,8 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
    Written by Brian Fox (bfox@ai.mit.edu). */
 
@@ -126,12 +125,14 @@ static char *info_internal_help_text[] = {
 ---------------\n"),
   N_("  %-10s  Pick first ... ninth item in node's menu.\n"),
   N_("  %-10s  Pick last item in node's menu.\n"),
-  N_("  %-10s  Search for a specified string in the index entries of this Info\n"),
-  N_("              file, and select the node referenced by the first entry found.\n"),
+  /* This string and the one below are one sentence, so they need to be
+     kept as one string for the translators.  */
+  N_("  %-10s  Search for a specified string in the index entries of this Info\n\
+              file, and select the node referenced by the first entry found.\n"),
   N_("  %-10s  Move to node specified by name.\n"),
   N_("              You may include a filename as well, as in (FILENAME)NODENAME.\n"),
-  N_("  %-10s  Search forward for a specified string,\n"),
-  N_("              and select the node in which the next occurrence is found.\n"),
+  N_("  %-10s  Search forward for a specified string,\n\
+              and select the node in which the next occurrence is found.\n"),
   N_("  %-10s  Search backward for a specified string\n"),
   N_("              and select the node in which the next occurrence is found.\n"),
   NULL
