@@ -1,13 +1,13 @@
 /* cmds.c -- Texinfo commands.
-   $Id: cmds.c,v 1.54 2004/11/26 00:48:35 karl Exp $
+   $Id: cmds.c,v 1.73 2007/07/01 21:20:31 karl Exp $
 
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
-   Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
+   Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,10 +15,10 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "system.h"
+#include "mbswidth.h"
 #include "cmds.h"
 #include "defun.h"
 #include "files.h"
@@ -39,11 +39,13 @@
 #include <time.h>
 #endif
 
-/* Options. */
+/* Simple commands defined and only called here. */
 static void cm_exampleindent (void),
      cm_firstparagraphindent (void),
-     cm_paragraphindent (void),
-     cm_novalidate (void);
+     cm_fonttextsize (void),
+     cm_frenchspacing (void),
+     cm_novalidate (void),
+     cm_paragraphindent (void);
 
 /* Internals. */
 static void cm_obsolete (int arg, int start, int end),
@@ -90,6 +92,7 @@ COMMAND command_table[] = {
   { "afourpaper", cm_ignore_line, NO_BRACE_ARGS },
   { "afourwide", cm_ignore_line, NO_BRACE_ARGS },
   { "alias", cm_alias, NO_BRACE_ARGS },
+  { "allowcodebreaks", cm_ignore_line, NO_BRACE_ARGS },
   { "anchor", cm_anchor, BRACE_ARGS },
   { "appendix", cm_appendix, NO_BRACE_ARGS },
   { "appendixsection", cm_appendixsec, NO_BRACE_ARGS },
@@ -200,9 +203,11 @@ COMMAND command_table[] = {
   { "float", cm_float, NO_BRACE_ARGS },
   { "flushleft", cm_flushleft, NO_BRACE_ARGS },
   { "flushright", cm_flushright, NO_BRACE_ARGS },
+  { "fonttextsize", cm_fonttextsize, NO_BRACE_ARGS },
   { "footnote", cm_footnote, NO_BRACE_ARGS}, /* self-arg eater */
   { "footnotestyle", cm_footnotestyle, NO_BRACE_ARGS },
   { "format", cm_format, NO_BRACE_ARGS },
+  { "frenchspacing", cm_frenchspacing, NO_BRACE_ARGS },
   { "ftable", cm_ftable, NO_BRACE_ARGS },
   { "group", cm_group, NO_BRACE_ARGS },
   { "heading", cm_heading, NO_BRACE_ARGS },
@@ -316,6 +321,7 @@ COMMAND command_table[] = {
   { "tab", cm_tab, NO_BRACE_ARGS },
   { "table", cm_table, NO_BRACE_ARGS },
   { "tex", cm_tex, NO_BRACE_ARGS },
+  { "textdegree", cm_special_char, BRACE_ARGS },
   { "tie", cm_tie, BRACE_ARGS },
   { "tieaccent", cm_accent, MAYBE_BRACE_ARGS },
   { "tindex", cm_tindex, NO_BRACE_ARGS },
@@ -451,9 +457,9 @@ cm_enddots (int arg)
 	}
       else
 	if (html && !in_fixed_width_font)
-	  insert_string ("<small class=\"enddots\">....</small>");
+	  insert_string ("<small class=\"enddots\">...</small>");
 	else
-	  add_word ("....");
+	  add_word ("...");
     }
 }
 
@@ -600,7 +606,7 @@ cm_comment (void)
   /* For HTML, do not output comments before HTML header is written,
      otherwise comments before @settitle cause an empty <title> in the
      header.  */
-  if ((html && html_output_head_p) || xml)
+  if ((html && output_head_p) || xml)
     {
       char *line;
       get_rest_of_line (0, &line);
@@ -624,6 +630,7 @@ cm_comment (void)
           /* Use insert for HTML, and XML when indentation is enabled.
              For Docbook, use add_char.  */
           if (xml && xml_indentation_increment > 0
+	      && output_paragraph_offset > 0
               && output_paragraph[output_paragraph_offset-1] != '\n')
             insert ('\n');
 
@@ -829,14 +836,16 @@ cm_code (int arg)
         { /* Use <samp> tag in general to get typewriter.  */
           if (arg == START)
             { /* If @samp specifically, add quotes a la TeX output.  */
-              if (STREQ (command, "samp")) add_char ('`');
-              add_word ("<samp>");
+              if (STREQ (command, "samp"))
+		add_word ("&lsquo;");
+	      insert_html_tag (arg, "samp");
             }
           insert_html_tag_with_attribute (arg, "span", "class=\"%s\"",command);
           if (arg == END)
             {
-              add_word ("</samp>");
-              if (STREQ (command, "samp")) add_char ('\'');
+	      insert_html_tag (arg, "samp");
+              if (STREQ (command, "samp"))
+		add_word ("&rsquo;");
             }
         }
     }
@@ -1100,15 +1109,16 @@ cm_strong (int arg, int start_pos, int end_pos)
     insert_html_tag (arg, "strong");
   else
     add_char ('*');
-  
+
   if (!xml && !html && !docbook && !no_headers
       && arg == END
       && end_pos - start_pos >= 6
       && (STRNCASEEQ ((char *) output_paragraph + start_pos, "*Note:", 6)
-          || STRNCASEEQ ((char *) output_paragraph + start_pos, "*Note ", 6)))
+          || STRNCASEEQ ((char *) output_paragraph + start_pos, "*Note ", 6))
+          )
     {
       /* Translators: "Note:" is literal here and should not be
-         translated.  @strong{Nota}, say, does not cause the problem.  */
+         translated.  A document with @strong{Nota}, say, is fine.  */
       warning (_("@strong{Note...} produces a spurious cross-reference in Info; reword to avoid that"));
       /* Adjust the output to avoid writing the bad xref.  */
       output_paragraph[start_pos + 5] = '_';
@@ -1283,17 +1293,23 @@ cm_w (int arg)
 
 /* An unbreakable word space.  Same as @w{ } for makeinfo, but different
    for TeX (the space stretches and stretches, and does not inhibit
-   hyphenation).  */
+   hyphenation).  For XML and HTML, insert the non-breaking-space
+   character and entity, respectively */
 void
 cm_tie (int arg)
 {
   if (arg == START)
+    if (html)
+      insert_string ("&nbsp;");
+    else if (xml)
+      insert_string ("&#xa0;");
+    else
     {
       cm_w (START);
       add_char (' ');
     }
   else
-    cm_w (END);
+    if (!html && !xml) cm_w (END);
 }
 
 /* Explain that this command is obsolete, thus the user shouldn't
@@ -1434,9 +1450,6 @@ cm_sp (void)
           /* close_paragraph generates an extra blank line.  */
           close_single_paragraph ();
 
-          if (lines && html && !executing_string)
-            html_output_head ();
-
           if (html)
             add_html_block_elt ("<pre class=\"sp\">\n");
 
@@ -1492,17 +1505,17 @@ cm_center (void)
 {
   if (xml)
     {
-      unsigned char *line;
+      char *line;
       xml_insert_element (CENTER, START);
-      get_rest_of_line (0, (char **)&line);
-      execute_string ("%s", (char *)line);
+      get_rest_of_line (0, &line);
+      execute_string ("%s", line);
       free (line);
       xml_insert_element (CENTER, END);
     }
   else
     {
-      int i, start, length;
-      unsigned char *line;
+      int i, start, length, width;
+      char *line;
       int save_indented_fill = indented_fill;
       int save_filling_enabled = filling_enabled;
       int fudge_factor = 1;
@@ -1515,8 +1528,8 @@ cm_center (void)
         add_html_block_elt ("<div align=\"center\">");
 
       inhibit_output_flushing ();
-      get_rest_of_line (0, (char **)&line);
-      execute_string ("%s", (char *)line);
+      get_rest_of_line (0, &line);
+      execute_string ("%s", line);
       free (line);
       uninhibit_output_flushing ();
       if (html)
@@ -1530,13 +1543,14 @@ cm_center (void)
 
            output_paragraph_offset = ++i;
            length = output_paragraph_offset - start;
+	   width = mbsnwidth ((char *)(output_paragraph + start), length, 0);
 
-           if (length < (fill_column - fudge_factor))
+           if (width < (fill_column - fudge_factor))
              {
                line = xmalloc (1 + length);
                memcpy (line, (char *)(output_paragraph + start), length);
 
-               i = (fill_column - fudge_factor - length) / 2;
+               i = (fill_column - fudge_factor - width) / 2;
                output_paragraph_offset = start;
 
                while (i--)
@@ -1563,7 +1577,10 @@ void
 cm_result (int arg)
 {
   if (arg == END)
-    add_word (html ? "=&gt;" : "=>");
+    if (html || xml)
+      xml_insert_entity ("rArr");
+    else
+      add_word ("=>");
 }
 
 /* What an expression expands to. */
@@ -1673,15 +1690,21 @@ handle_include (int verbatim_include)
   if (!insertion_stack)
     close_paragraph ();  /* No blank lines etc. if not at outer level.  */
     
+  if (macro_expansion_output_stream && verbatim_include)
+    {
+      me_append_before_this_command ();
+      return;
+    }
+    
   get_rest_of_line (0, &arg);
   /* We really only want to expand @value, but it's easier to just do
      everything.  TeX will only work with @value.  */
   filename = text_expansion (arg);
   free (arg);
-
+  
   if (macro_expansion_output_stream && !executing_string)
     remember_itext (input_text, input_text_offset);
-
+  
   pushfile ();
 
   /* In verbose mode we print info about including another file. */
@@ -1816,7 +1839,7 @@ cm_firstparagraphindent (void)
 
   get_rest_of_line (1, &arg);
   if (set_firstparagraphindent (arg) != 0)
-    line_error (_("Bad argument to %c%s"), COMMAND_PREFIX, command);
+    line_error (_("Bad argument to @%s: %s"), command, arg);
 
   free (arg);
 }
@@ -1834,7 +1857,8 @@ cm_colon (void)
         {
           /* Erase literal character that's there, except `>', which is
              part of the XML tag.  */
-          if (output_paragraph[output_paragraph_offset-1] != '>')
+          if (output_paragraph_offset > 0
+	      && output_paragraph[output_paragraph_offset-1] != '>')
             output_paragraph_offset--;
 
           switch (input_text[input_text_offset-3])
@@ -1861,7 +1885,7 @@ cm_colon (void)
 void
 cm_punct (int arg)
 {
-  if (xml && !docbook)
+  if (xml && !docbook && input_text_offset > 0)
     {
       switch (input_text[input_text_offset-1])
         {
@@ -1881,3 +1905,43 @@ cm_punct (int arg)
       insert_self (arg);
     }
 }
+
+
+/* If @frenchspacing is in effect, avoid outputting extra spaces after
+   sentence-ending periods.  Actually, we explicitly do this only in one
+   tiny case (see add_char in makeinfo.c).  Usually we just output
+   whatever the user gives us.  */
+void
+cm_frenchspacing (void)
+{
+  char *val;
+  get_rest_of_line (1, &val);
+
+  if (STREQ (val, "on")) {
+    french_spacing = 1;
+  } else if (STREQ (val, "off")) {
+    french_spacing = 0;
+  } else {
+    line_error (_("Expected @%s on or off, not `%s'"), command, val);
+  }
+  
+  if (xml && !docbook) {
+    xml_insert_element_with_attribute (FRENCHSPACING, START,
+                                       "val=\"%s\"", val);
+    xml_insert_element (FRENCHSPACING, END);
+  }
+}
+
+
+/* Body font size.  This is only for TeX, so we're just checking
+   validity here.  Don't think we should even pass it on to XML.  */
+void
+cm_fonttextsize (void)
+{
+  char *val;
+  get_rest_of_line (1, &val);
+
+  if (! (STREQ (val, "10") || STREQ (val, "off"))) {
+    line_error (_("Only @%s 10 or 11 is supported, not `%s'"), command, val);
+  }
+}
