@@ -1,22 +1,21 @@
 /* cmds.h -- declarations for cmds.c.
-   $Id: cmds.h,v 1.4 2004/02/24 22:52:52 dirt Exp $
+   $Id: cmds.h,v 1.12 2007/07/01 21:20:32 karl Exp $
 
-   Copyright (C) 1998, 1999, 2002, 2003, 2004 Free Software Foundation,
-   Inc.
+   Copyright (C) 1998, 1999, 2002, 2003, 2004, 2007
+   Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with this program; if not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifndef CMDS_H
 #define CMDS_H
@@ -109,6 +108,7 @@ extern void cm_LaTeX (int arg),
 
 /* Emphasis and markup.  */
 extern void cm_acronym (int arg),
+  cm_abbr (int arg),
   cm_b (int arg),
   cm_cite (int arg, int position),
   cm_code (int arg),
@@ -122,10 +122,12 @@ extern void cm_acronym (int arg),
   cm_math (int arg),
   cm_not_fixed_width (int arg, int start, int end),
   cm_r (int arg),
+  cm_sansserif (int arg),
   cm_sc (int arg, int start_pos, int end_pos),
+  cm_slanted (int arg),
   cm_strong (int arg, int start_pos, int end_pos),
   cm_tt (int arg),
-  cm_url (int arg, int start, int end),
+  cm_indicate_url (int arg, int start, int end),
   cm_var (int arg, int start_pos, int end_pos),
   cm_verb (int arg);
 
