@@ -1,12 +1,13 @@
 /* lang.h -- declarations for language codes etc.
-   $Id: lang.h,v 1.6.2.1 2007/06/27 17:11:02 karl Exp $
+   $Id: lang.h,v 1.13 2007/07/01 21:20:32 karl Exp $
 
-   Copyright (C) 1999, 2001, 2002, 2003, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2006, 2007
+   Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
    Originally written by Karl Heinz Marbaise <kama@hippo.fido.de>.  */
 
@@ -27,33 +27,18 @@
  * These code are the ISO-639 two letter codes.
  */
 typedef enum
-{
-  aa,  ab,  af,  am,  ar,  as,  ay,  az,
-  ba,  be,  bg,  bh,  bi,  bn,  bo,  br,
-  ca,  co,  cs,  cy,
-  da,  de,  dz,
-  el,  en,  eo,  es,  et,  eu,
-  fa,  fi,  fj,  fo,  fr,  fy,
-  ga,  gd,  gl,  gn,  gu,
-  ha,  he,  hi,  hr,  hu,  hy,
-  ia,  id,  ie,  ik,  is,  it,  iu,
-  ja,  jw,
-  ka,  kk,  kl,  km,  kn,  ko,  ks,  ku,  ky,
-  la,  ln,  lo,  lt,  lv,
-  mg,  mi,  mk,  ml,  mn,  mo,  mr,  ms,  mt,  my,
-  na,  ne,  nl,  no,
-  oc,  om,  or,
-  pa,  pl,  ps,  pt,
-  qu,
-  rm,  rn,  ro,  ru,  rw,
-  sa,  sd,  sg,  sh,  si,  sk,  sl,  sm,  sn,  so,  sq,  sr,  ss,  st,  su,  sv,  sw,
-  ta,  te,  tg,  th,  ti,  tk,  tl,  tn,  to,  tr,  ts,  tt,  tw,
-  ug,  uk,  ur,  uz,
-  vi,  vo,
-  wo,
-  xh,
-  yi,  yo,
-  za,  zh,  zu,
+{ 
+  aa, ab, ae, af, ak, am, an, ar, as, av, ay, az, ba, be, bg, bh, bi,
+  bm, bn, bo, br, bs, ca, ce, ch, co, cr, cs, cu, cv, cy, da, de, dv,
+  dz, ee, el, en, eo, es, et, eu, fa, ff, fi, fj, fo, fr, fy, ga, gd,
+  gl, gn, gu, gv, ha, he, hi, ho, hr, ht, hu, hy, hz, ia, id, ie, ig,
+  ii, ik, io, is, it, iu, ja, jv, ka, kg, ki, kj, kk, kl, km, kn, ko,
+  kr, ks, ku, kv, kw, ky, la, lb, lg, li, ln, lo, lt, lu, lv, mg, mh,
+  mi, mk, ml, mn, mo, mr, ms, mt, my, na, nb, nd, ne, ng, nl, nn, no,
+  nr, nv, ny, oc, oj, om, or, os, pa, pi, pl, ps, pt, qu, rm, rn, ro,
+  ru, rw, sa, sc, sd, se, sg, si, sk, sl, sm, sn, so, sq, sr, ss, st,
+  su, sv, sw, ta, te, tg, th, ti, tk, tl, tn, to, tr, ts, tt, tw, ty,
+  ug, uk, ur, uz, ve, vi, vo, wa, wo, xh, yi, yo, za, zh, zu,
   last_language_code
 } language_code_type;
 
@@ -94,6 +79,9 @@ typedef enum {
   ISO_8859_13,
   ISO_8859_14,
   ISO_8859_15,
+  KOI8_R,
+  KOI8_U,
+  UTF_8,
   last_encoding_code
 } encoding_code_type;
 
@@ -113,6 +101,7 @@ typedef struct
   char *html;        /* HTML equivalent like umlaut auml => &auml; */
   byte_t bytecode;   /* 8-Bit Code (ISO 8859-1,...) */
   unicode_t unicode; /* Unicode in U+ convention */
+  char *translit;    /* 7-bit transliteration */
 } iso_map_type;
 
 /* Information about the document encoding. */
@@ -145,4 +134,8 @@ extern void cm_accent_umlaut (int arg, int start, int end),
 
 extern char *current_document_encoding (void);
 
+extern const char *lang_transliterate_char (byte_t ch);
+
+extern char *document_language;
+
 #endif /* not LANG_H */
